@@ -21,17 +21,17 @@ build_time_vars = {'ABIFLAGS': 'm',
  'CC': 'gcc -pthread',
  'CCSHARED': '-fPIC',
  'CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 -Wall '
-           '-march=armv6 -mfloat-abi=hard -mfpu=vfp -O2 -pipe '
+           '-march=armv6 -mfloat-abi=hard -mfpu=vfp -O3 -pipe '
            '-fstack-protector-strong -fno-plt -march=armv6 -mfloat-abi=hard '
-           '-mfpu=vfp -O2 -pipe -fstack-protector-strong -fno-plt -march=armv6 '
-           '-mfloat-abi=hard -mfpu=vfp -O2 -pipe -fstack-protector-strong '
+           '-mfpu=vfp -O3 -pipe -fstack-protector-strong -fno-plt -march=armv6 '
+           '-mfloat-abi=hard -mfpu=vfp -O3 -pipe -fstack-protector-strong '
            '-fno-plt',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CFLAGS_NODIST': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
- 'CONFIGURE_CFLAGS': '-march=armv6 -mfloat-abi=hard -mfpu=vfp -O2 -pipe '
+ 'CONFIGURE_CFLAGS': '-march=armv6 -mfloat-abi=hard -mfpu=vfp -O3 -pipe '
                      '-fstack-protector-strong -fno-plt',
  'CONFIGURE_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                             '-Wno-unused-parameter '
@@ -45,15 +45,15 @@ build_time_vars = {'ABIFLAGS': 'm',
                 "'--with-system-expat' '--with-dbmliborder=gdbm:ndbm' "
                 "'--with-system-ffi' '--with-system-libmpdec' "
                 "'--enable-loadable-sqlite-extensions' '--without-ensurepip' "
-                "'CFLAGS=-march=armv6 -mfloat-abi=hard -mfpu=vfp -O2 -pipe "
+                "'CFLAGS=-march=armv6 -mfloat-abi=hard -mfpu=vfp -O3 -pipe "
                 "-fstack-protector-strong -fno-plt' "
                 "'LDFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now' "
                 "'CPPFLAGS=-D_FORTIFY_SOURCE=2'",
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.7m',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/build/python/src/Python-3.7.0/coverage.info',
- 'COVERAGE_REPORT': '/build/python/src/Python-3.7.0/lcov-report',
+ 'COVERAGE_INFO': '/build/python/src/Python-3.7.1/coverage.info',
+ 'COVERAGE_REPORT': '/build/python/src/Python-3.7.1/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-I. -I./Include -D_FORTIFY_SOURCE=2 -D_FORTIFY_SOURCE=2',
@@ -545,7 +545,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'MACOSX_DEPLOYMENT_TARGET': '',
  'MAINCC': 'gcc -pthread',
  'MAJOR_IN_MKDEV': 0,
- 'MAJOR_IN_SYSMACROS': 0,
+ 'MAJOR_IN_SYSMACROS': 1,
  'MAKESETUP': './Modules/makesetup',
  'MANDIR': '/usr/share/man',
  'MKDIR_P': '/usr/bin/mkdir -p',
@@ -607,14 +607,14 @@ build_time_vars = {'ABIFLAGS': 'm',
  'PYTHONFRAMEWORKPREFIX': '',
  'PYTHONPATH': '',
  'PYTHON_FOR_BUILD': './python -E',
- 'PYTHON_FOR_REGEN': 'python3',
+ 'PYTHON_FOR_REGEN': 'python3.7',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 -Wall '
-              '-march=armv6 -mfloat-abi=hard -mfpu=vfp -O2 -pipe '
+              '-march=armv6 -mfloat-abi=hard -mfpu=vfp -O3 -pipe '
               '-fstack-protector-strong -fno-plt -march=armv6 -mfloat-abi=hard '
-              '-mfpu=vfp -O2 -pipe -fstack-protector-strong -fno-plt '
-              '-march=armv6 -mfloat-abi=hard -mfpu=vfp -O2 -pipe '
+              '-mfpu=vfp -O3 -pipe -fstack-protector-strong -fno-plt '
+              '-march=armv6 -mfloat-abi=hard -mfpu=vfp -O3 -pipe '
               '-fstack-protector-strong -fno-plt',
  'PY_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                      '-Wno-unused-parameter -Wno-missing-field-initializers '
@@ -622,11 +622,11 @@ build_time_vars = {'ABIFLAGS': 'm',
                      '-Werror=implicit-function-declaration',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 '
-                   '-Wall -march=armv6 -mfloat-abi=hard -mfpu=vfp -O2 -pipe '
+                   '-Wall -march=armv6 -mfloat-abi=hard -mfpu=vfp -O3 -pipe '
                    '-fstack-protector-strong -fno-plt -march=armv6 '
-                   '-mfloat-abi=hard -mfpu=vfp -O2 -pipe '
+                   '-mfloat-abi=hard -mfpu=vfp -O3 -pipe '
                    '-fstack-protector-strong -fno-plt -march=armv6 '
-                   '-mfloat-abi=hard -mfpu=vfp -O2 -pipe '
+                   '-mfloat-abi=hard -mfpu=vfp -O3 -pipe '
                    '-fstack-protector-strong -fno-plt -std=c99 -Wextra '
                    '-Wno-unused-result -Wno-unused-parameter '
                    '-Wno-missing-field-initializers -Wno-cast-function-type '
@@ -640,18 +640,17 @@ build_time_vars = {'ABIFLAGS': 'm',
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
  'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv '
-                        '-O3 -Wall -march=armv6 -mfloat-abi=hard -mfpu=vfp -O2 '
+                        '-O3 -Wall -march=armv6 -mfloat-abi=hard -mfpu=vfp -O3 '
                         '-pipe -fstack-protector-strong -fno-plt -march=armv6 '
-                        '-mfloat-abi=hard -mfpu=vfp -O2 -pipe '
+                        '-mfloat-abi=hard -mfpu=vfp -O3 -pipe '
                         '-fstack-protector-strong -fno-plt -march=armv6 '
-                        '-mfloat-abi=hard -mfpu=vfp -O2 -pipe '
+                        '-mfloat-abi=hard -mfpu=vfp -O3 -pipe '
                         '-fstack-protector-strong -fno-plt -std=c99 -Wextra '
                         '-Wno-unused-result -Wno-unused-parameter '
                         '-Wno-missing-field-initializers '
                         '-Wno-cast-function-type '
                         '-Werror=implicit-function-declaration -I. -I./Include '
                         '-D_FORTIFY_SOURCE=2 -D_FORTIFY_SOURCE=2 -fPIC',
- 'PY_WARN_ON_C_LOCALE': 1,
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 1,
  'Py_HASH_ALGORITHM': 0,
@@ -659,7 +658,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python/src/Python-3.7.0',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python/src/Python-3.7.1',
  'SCRIPTDIR': '/usr/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SGI_ABI': '@SGI_ABI@',
@@ -701,9 +700,9 @@ build_time_vars = {'ABIFLAGS': 'm',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python/src/Python-3.7.0 ./python',
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python/src/Python-3.7.1 ./python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python/src/Python-3.7.0 ./python '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python/src/Python-3.7.1 ./python '
                './Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 1200,
  'TIMEMODULE_LIB': 0,
@@ -711,7 +710,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'TM_IN_SYS_TIME': 0,
  'UNICODE_DEPS': '\\',
  'UNIVERSALSDK': '',
- 'UPDATE_FILE': 'python3 ./Tools/scripts/update_file.py',
+ 'UPDATE_FILE': 'python3.7 ./Tools/scripts/update_file.py',
  'USE_COMPUTED_GOTOS': 1,
  'VERSION': '3.7',
  'WINDOW_HAS_FLAGS': 1,
@@ -724,8 +723,8 @@ build_time_vars = {'ABIFLAGS': 'm',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/build/python/src/Python-3.7.0',
- 'abs_srcdir': '/build/python/src/Python-3.7.0',
+ 'abs_builddir': '/build/python/src/Python-3.7.1',
+ 'abs_srcdir': '/build/python/src/Python-3.7.1',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
